part of 'building_and_structure_bloc.dart';

class BuildingAndStructureState extends Equatable {
  const BuildingAndStructureState();

  @override
  List<Object> get props => [];
}

class BuildingAndStructureOfflineInitial extends BuildingAndStructureState {
  @override
  List<Object> get props => [];
}

class BuildingAndStructureLoaded extends BuildingAndStructureState {
  final List<BldgAndStructure> bldgAndStructure;

  const BuildingAndStructureLoaded({required this.bldgAndStructure});
  @override
  List<Object> get props => [bldgAndStructure];
}

class LoadSpecificBuildingAndStructure extends BuildingAndStructureState {
  final BldgAndStructure bldgAndStructure;

  const LoadSpecificBuildingAndStructure({required this.bldgAndStructure});
  @override
  List<Object> get props => [bldgAndStructure];
}

class ShowBldgAndStructuresScreen extends BuildingAndStructureState {}

class BuildingAndStructureErrorState extends BuildingAndStructureState {
  const BuildingAndStructureErrorState(this.error);
  final String error;

  @override
  List<Object> get props => [error];
}

class BuildingAndStructureDeletedState extends BuildingAndStructureState {
  final bool success;
  const BuildingAndStructureDeletedState({required this.success});
  @override
  List<Object> get props => [success];
}
